@@ -41,10 +41,17 @@ func main() {
 	flushOutput()
 }
 
+func defaultVersion() string {
+	if v := os.Getenv("UNICODE_VERSION"); v != "" {
+		return v
+	}
+	return unicode.Version
+}
+
 var dataURL = flag.String("data", "", "full URL for UnicodeData.txt; defaults to --url/UnicodeData.txt")
 var casefoldingURL = flag.String("casefolding", "", "full URL for CaseFolding.txt; defaults to --url/CaseFolding.txt")
 var url = flag.String("url",
-	"http://www.unicode.org/Public/9.0.0/ucd/",
+	"http://www.unicode.org/Public/"+defaultVersion()+"/ucd/",
 	"URL of Unicode database directory")
 var tablelist = flag.String("tables",
 	"all",
@@ -169,7 +176,7 @@ var category = map[string]bool{
 // UnicodeData.txt has form:
 //	0037;DIGIT SEVEN;Nd;0;EN;;7;7;7;N;;;;;
 //	007A;LATIN SMALL LETTER Z;Ll;0;L;;;;;N;;;005A;;005A
-// See http://www.unicode.org/reports/tr44/ for a full explanation
+// See https://www.unicode.org/reports/tr44/ for a full explanation
 // The fields:
 const (
 	FCodePoint = iota
@@ -225,7 +232,7 @@ type Char struct {
 // Scripts.txt has form:
 //	A673          ; Cyrillic # Po       SLAVONIC ASTERISK
 //	A67C..A67D    ; Cyrillic # Mn   [2] COMBINING CYRILLIC KAVYKA..COMBINING CYRILLIC PAYEROK
-// See http://www.unicode.org/Public/5.1.0/ucd/UCD.html for full explanation
+// See https://www.unicode.org/Public/5.1.0/ucd/UCD.html for full explanation
 
 type Script struct {
 	lo, hi uint32 // range of code points
@@ -1125,12 +1132,6 @@ func printLatinProperties() {
 	printf("}\n\n")
 }
 
-type runeSlice []rune
-
-func (p runeSlice) Len() int           { return len(p) }
-func (p runeSlice) Less(i, j int) bool { return p[i] < p[j] }
-func (p runeSlice) Swap(i, j int)      { p[i], p[j] = p[j], p[i] }
-
 func printCasefold() {
 	// Build list of case-folding groups attached to each canonical folded char (typically lower case).
 	var caseOrbit = make([][]rune, MaxChar+1)
@@ -1177,7 +1178,9 @@ func printCasefold() {
 		if orb == nil {
 			continue
 		}
-		sort.Sort(runeSlice(orb))
+		sort.Slice(orb, func(i, j int) bool {
+			return orb[i] < orb[j]
+		})
 		c := orb[len(orb)-1]
 		for _, d := range orb {
 			chars[c].caseOrbit = d
